@@ -3,11 +3,12 @@ use warnings;
 
 package SVN::Hooks::AllowPropChange;
 {
-  $SVN::Hooks::AllowPropChange::VERSION = '1.13';
+  $SVN::Hooks::AllowPropChange::VERSION = '1.21';
 }
 # ABSTRACT: Allow changes in revision properties.
 
 use Carp;
+use Data::Util qw(:check);
 use SVN::Hooks;
 
 use Exporter qw/import/;
@@ -23,10 +24,9 @@ sub ALLOW_PROP_CHANGE {
     my @whos;
 
     foreach my $arg (@args) {
-	if (not ref $arg or ref $arg eq 'Regexp') {
+	if (is_string($arg) || is_rx($arg)) {
 	    push @whos, $arg;
-	}
-	else {
+	} else {
 	    croak "$HOOK: invalid argument '$arg'\n";
 	}
     }
@@ -53,17 +53,15 @@ sub pre_revprop_change {
 
     foreach my $spec (@Specs) {
 	my ($prop, $whos) = @$spec;
-	if (! ref $prop) {
+	if (is_string($prop)) {
 	    next if $propname ne $prop;
-	}
-	else {
+	} else {
 	    next if $propname !~ $prop;
 	}
 	for my $who (@$whos) {
-	    if (! ref $who) {
+	    if (is_string($who)) {
 		return if $author eq $who;
-	    }
-	    else {
+	    } else {
 		return if $author =~ $who;
 	    }
 	}
@@ -75,6 +73,7 @@ sub pre_revprop_change {
 1; # End of SVN::Hooks::AllowPropChange
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -83,7 +82,7 @@ SVN::Hooks::AllowPropChange - Allow changes in revision properties.
 
 =head1 VERSION
 
-version 1.13
+version 1.21
 
 =head1 SYNOPSIS
 
@@ -145,10 +144,9 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by CPqD.
+This software is copyright (c) 2013 by CPqD.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
